####################
データの解析
####################

.. warning::

    :py:mod:`ebilab.analysis` モジュールは完成していません。
    今後のバージョンでは後方互換性がない場合があります。

計測などの実験で得たデータには、データの整形やフィッティング・グラフ化など、さまざまな処理を行なうことが少なくありません。
また、処理を変えながらデータ解析を行うなど、そのような処理のスクリプトは往々にして複雑になり、整理することも困難になります。

本パッケージを使うと、ソースコードの整理が容易になります。また、生成したデータにも自動で名前が付き、整理が容易になります。

イメージとしては以下のコードです。

.. code-block:: python

    from ebilab.analysis import input

    input("electrodes-R.csv") \
        .plot(plot) \
        .apply(filter_data) \
        .plot(plot) \
        .apply(filter_data2) \
        .plot(plot)

